@@ -11,6 +11,9 @@ class OpenSUSE:
         " zypper update -y"
     ]
 
+# For installing Minigalaxy 
+    OpenSUSE_Minigalaxy = " zypper install -y minigalaxy"
+
 # For installing Lutris
     OpenSUSE_Lutris = " zypper install -y lutris"       
 
@@ -21,7 +24,7 @@ class OpenSUSE:
     def OpenSUSE_Heroic(self): 
         whoami = str(subprocess.getoutput("whoami"))
         if whoami == "root":
-           print("Please run LibreGaming for OpenSUSE Heroic without sudo or doas command, so that it installs correctly")
+           print("\n\tPlease run LibreGaming for OpenSUSE Heroic without sudo or doas command, so that it installs correctly\n")
         else:
             print('Downloading Heroic latest AppImage')
             url = 'https://api.github.com/repos/Heroic-Games-Launcher/HeroicGamesLauncher/releases/latest'
